changeset 1623:bdd72dc49c66

* bytecomp.el: Declare unread-command-char an obsolete variable. * vip.el (vip-escape-to-emacs, vip-prefix-arg-value, vip-prefix-arg-com): Use unread-command-event instead of unread-command-char; respect its new semantics. * sun-mouse.el (mouse-second-hit): Same.
author Jim Blandy <jimb@redhat.com>
date Mon, 16 Nov 1992 01:43:35 +0000
parents dd7b72d023ad
children 48b04808802d
files lisp/term/sun-mouse.el
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/term/sun-mouse.el	Mon Nov 16 01:43:07 1992 +0000
+++ b/lisp/term/sun-mouse.el	Mon Nov 16 01:43:35 1992 +0000
@@ -318,12 +318,12 @@
     (let ((pc1 (read-char)))
       (if (or (not (equal pc1 mouse-prefix1))
 	      (sit-for-millisecs 3))	; a mouse prefix will have second char
-	  (progn (setq unread-command-char pc1)	; Can get away with one unread.
+	  (progn (setq unread-command-event pc1)	; Can get away with one unread.
 		 nil)			; Next input not mouse event.
 	(let ((pc2 (read-char)))
 	  (if (not (equal pc2 mouse-prefix2))
-	      (progn (setq unread-command-char pc1) ; put back the ^X
-;;; Too bad can't do two: (setq unread-command-char (list pc1 pc2))
+	      (progn (setq unread-command-event pc1) ; put back the ^X
+;;; Too bad can't do two: (setq unread-command-event (list pc1 pc2))
 		(ding)			; user will have to retype that pc2.
 		nil)			; This input is not a mouse event.
 	    ;; Next input has mouse prefix and is within time limit.